==> uncss-0.1.1.tgz: package/lib/uncss.js <==
/*jslint node: true, plusplus: true */
(function () {
    "use strict";
    var async             = require('async'),
        compressor        = require('csso'),
        fs                = require('fs'),
        htmlparser_module = require('htmlparser'),
        parse_css         = require('css-parse'),
        soupselect        = require('soupselect').select,

        htmlparser,
        options,
        parsed_css,
        parser_handler;

    function rule_to_css(decl) {
        return decl.map(function (d) {
            return '\t'
                 + d.property
                 + ': '
                 + d.value
                + ';';
        }).join('\n') + '\n';
    }

    /* The bulk of the work happens here */
    parser_handler = new htmlparser_module.DefaultHandler(function (error, dom) {
        if (error) {
            throw error;
        } else {
            /* HTML parsed successfully, proceed with css
             *  Two steps: remove the unused selectors from the selector array
             *             filter the rules with no selectors (i.e. the rule was not used)
             */
            var used_rules = parsed_css.stylesheet.rules.map(function (rule) {
                /* This is the syntax of css-parse
                 *  rule = {
                 *      "selectors": [ ... ],
                 *      "declarations": [ ... ]
                 *  }
                 *  
                 */
                if (rule.selectors) {
                    var used_selectors = rule.selectors.filter(function (selector) {
                        return (soupselect(dom, selector).length > 0);
                    });
                    /* Case 1: 
                     * rule = {
                     *      "selectors": ['a', 'c'],
                     *      "declarations": [ ... ]
                     *  }
                     *
                     * Case 2:
                     * rule = {
                     *      "selectors": [],
                     *      "declarations": [ ... ]
                     * }
                     */
                    if (used_selectors.length > 0) {
                        /* Case 1 */
                        return {
                            'selectors': used_selectors,
                            'declarations': rule.declarations
                        };
                    }
                }
                /* Case 2, or rule isn't a selector array (for example, a comment) */
                return {};

            }).filter(function (rule) {
                return rule.selectors !== undefined;
            }),
                uncss = '',
                i;


            for (i = 0; i < used_rules.length; i++) {
                uncss += used_rules[i].selectors.join(', ')
                      + ' {\n'
                      + rule_to_css(used_rules[i].declarations)
                      + '}\n';
            }
            /* Compress CSS */
            if (options.compress) {
                uncss = compressor.justDoIt(uncss);
            }
            if (options.outfile) {
                fs.writeFile(options.outfile, uncss, function (err) {
                    if (err) {
                        throw err;
                    }
                    console.log('uncss: wrote %s', options.outfile);
                });
            } else {
                console.log(uncss);
            }
        }
    });

    module.exports = function (css_files, html_files, opt) {
        options = opt;
        htmlparser = new htmlparser_module.Parser(parser_handler);

        /* Parse all the CSS files in series, and concatenate them */
        async.map(css_files, fs.readFile, function (error_css, css_file_contents) {
            if (error_css) {
                throw error_css;
            }
            parsed_css = parse_css(css_file_contents.join('\n'));
            /* Parse the HTML and, again, contcatenate all the files */
            async.map(html_files, fs.readFile, function (error_html, html_file_contents) {
                if (error_html) {
                    throw error_html;
                }
                /* Pass to the main function */
                htmlparser.parseComplete(html_file_contents.join('\n'));
            });
        });
    };
}());

==> uncss-0.1.2.tgz: package/lib/uncss.js <==
/*jslint node: true, plusplus: true */
(function () {
    "use strict";
    var async             = require('async'),
        compressor        = require('csso'),
        fs                = require('fs'),
        htmlparser_module = require('htmlparser'),
        parse_css         = require('css-parse'),
        soupselect        = require('soupselect').select,

        htmlparser,
        options,
        parsed_css,
        parser_handler;

    function rule_to_css(decl) {
        return decl.map(function (d) {
            return '\t'
                 + d.property
                 + ': '
                 + d.value
                + ';';
        }).join('\n') + '\n';
    }

    /* The bulk of the work happens here */
    parser_handler = new htmlparser_module.DefaultHandler(function (error, dom) {
        if (error) {
            throw error;
        } else {
            /* HTML parsed successfully, proceed with css
             *  Two steps: remove the unused selectors from the selector array
             *             filter the rules with no selectors (i.e. the rule was not used)
             */
            var i,
                uncss = '',
                used_rules = parsed_css.stylesheet.rules.map(function (rule) {
                    /* This is the syntax of css-parse
                     *  rule = {
                     *      "selectors": [ ... ],
                     *      "declarations": [ ... ]
                     *  }
                     *  
                     */
                    if (rule.selectors) {
                        var used_selectors = rule.selectors.filter(function (selector) {
                            return (soupselect(dom, selector).length > 0);
                        });
                        /* Case 1: 
                         * rule = {
                         *      "selectors": ['a', 'c'],
                         *      "declarations": [ ... ]
                         *  }
                         *
                         * Case 2:
                         * rule = {
                         *      "selectors": [],
                         *      "declarations": [ ... ]
                         * }
                         */
                        if (used_selectors.length > 0) {
                            /* Case 1 */
                            return {
                                'selectors': used_selectors,
                                'declarations': rule.declarations
                            };
                        }
                    }
                    /* Case 2, or rule isn't a selector array (for example, a comment) */
                    return {};

                }).filter(function (rule) {
                    return rule.selectors !== undefined;
                });

            for (i = 0; i < used_rules.length; i++) {
                uncss += used_rules[i].selectors.join(', ')
                      + ' {\n'
                      + rule_to_css(used_rules[i].declarations)
                      + '}\n';
            }
            /* Compress CSS */
            if (options.compress) {
                uncss = compressor.justDoIt(uncss);
            }
            if (options.outfile) {
                fs.writeFile(options.outfile, uncss, function (err) {
                    if (err) {
                        throw err;
                    }
                    console.log('uncss: wrote %s', options.outfile);
                });
            } else {
                return uncss;
            }
        }
    });

    module.exports = function (css_files, html_files, opt) {
        options = opt;
        htmlparser = new htmlparser_module.Parser(parser_handler);

        /* Parse all the CSS files in series, and concatenate them */
        async.map(css_files, fs.readFile, function (error_css, css_file_contents) {
            if (error_css) {
                throw error_css;
            }
            parsed_css = parse_css(css_file_contents.join('\n'));
            /* Parse the HTML and, again, contcatenate all the files */
            async.map(html_files, fs.readFile, function (error_html, html_file_contents) {
                if (error_html) {
                    throw error_html;
                }
                /* Pass to the main function */
                htmlparser.parseComplete(html_file_contents.join('\n'));
            });
        });
    };
}());
